==> jc-1.4.0.tar.gz: java/lang/ArrayIndexOutOfBoundsException.h <==
// public class java.lang.ArrayIndexOutOfBoundsException

// class file dependencies
// @dep_class 49615c3d39443a4c java_lang_ArrayIndexOutOfBoundsException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 3cdfed1e0ad1a3d6 java_lang_IndexOutOfBoundsException
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_IndexOutOfBoundsException

#include "java/lang/IndexOutOfBoundsException.h"

#ifndef _JC_java_lang_ArrayIndexOutOfBoundsException_H_
#define _JC_java_lang_ArrayIndexOutOfBoundsException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_ArrayIndexOutOfBoundsException$sub_refs	_jc_java_lang_ArrayIndexOutOfBoundsException$sub_refs;
typedef struct _jc_java_lang_ArrayIndexOutOfBoundsException$sub_nonrefs	_jc_java_lang_ArrayIndexOutOfBoundsException$sub_nonrefs;
typedef struct _jc_java_lang_ArrayIndexOutOfBoundsException$refs	_jc_java_lang_ArrayIndexOutOfBoundsException$refs;
typedef struct _jc_java_lang_ArrayIndexOutOfBoundsException$nonrefs	_jc_java_lang_ArrayIndexOutOfBoundsException$nonrefs;
typedef struct _jc_java_lang_ArrayIndexOutOfBoundsException$object	_jc_java_lang_ArrayIndexOutOfBoundsException$object;

typedef struct _jc_java_lang_ArrayIndexOutOfBoundsException$fields_struct	_jc_java_lang_ArrayIndexOutOfBoundsException$fields_struct;
typedef const struct _jc_java_lang_ArrayIndexOutOfBoundsException$vmethods	_jc_java_lang_ArrayIndexOutOfBoundsException$vmethods;
typedef const struct _jc_java_lang_ArrayIndexOutOfBoundsException$vtable	_jc_java_lang_ArrayIndexOutOfBoundsException$vtable;
typedef const struct _jc_java_lang_ArrayIndexOutOfBoundsException$vtype	_jc_java_lang_ArrayIndexOutOfBoundsException$vtype;

// Class fields structure
struct _jc_java_lang_ArrayIndexOutOfBoundsException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_ArrayIndexOutOfBoundsException$fields_struct _jc_java_lang_ArrayIndexOutOfBoundsException$class_fields;

// Constructors
extern void _jc_java_lang_ArrayIndexOutOfBoundsException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_ArrayIndexOutOfBoundsException$object *);
extern void _jc_java_lang_ArrayIndexOutOfBoundsException$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_lang_ArrayIndexOutOfBoundsException$object *, jint);
extern void _jc_java_lang_ArrayIndexOutOfBoundsException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_ArrayIndexOutOfBoundsException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_lang_ArrayIndexOutOfBoundsException$vmethods {
};

// Vtable
struct _jc_java_lang_ArrayIndexOutOfBoundsException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_IndexOutOfBoundsException$vmethods	java_lang_IndexOutOfBoundsException;
	_jc_java_lang_ArrayIndexOutOfBoundsException$vmethods	java_lang_ArrayIndexOutOfBoundsException;
};

// Vtype
struct _jc_java_lang_ArrayIndexOutOfBoundsException$vtype {
	_jc_type			type;
	_jc_java_lang_ArrayIndexOutOfBoundsException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_ArrayIndexOutOfBoundsException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_ArrayIndexOutOfBoundsException$refs {
    _jc_java_lang_ArrayIndexOutOfBoundsException$sub_refs	java_lang_ArrayIndexOutOfBoundsException;
    _jc_java_lang_IndexOutOfBoundsException$sub_refs	java_lang_IndexOutOfBoundsException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_ArrayIndexOutOfBoundsException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_ArrayIndexOutOfBoundsException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_IndexOutOfBoundsException$sub_nonrefs	java_lang_IndexOutOfBoundsException;
    _jc_java_lang_ArrayIndexOutOfBoundsException$sub_nonrefs	java_lang_ArrayIndexOutOfBoundsException;
};

// Object instance structure
struct _jc_java_lang_ArrayIndexOutOfBoundsException$object {
	_jc_java_lang_ArrayIndexOutOfBoundsException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_ArrayIndexOutOfBoundsException$vtype	*vtype;
	_jc_java_lang_ArrayIndexOutOfBoundsException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_ArrayIndexOutOfBoundsException$vtype _jc_java_lang_ArrayIndexOutOfBoundsException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_ArrayIndexOutOfBoundsException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_ArrayIndexOutOfBoundsException$class_object;

#endif	/* _JC_java_lang_ArrayIndexOutOfBoundsException_H_ */

==> jc-1.4.6.tar.gz: java/lang/ArrayIndexOutOfBoundsException.h <==
// public class java.lang.ArrayIndexOutOfBoundsException

// class file dependencies
// @dep_class 49615c3d39443a4c java_lang_ArrayIndexOutOfBoundsException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 3cdfed1e0ad1a3d6 java_lang_IndexOutOfBoundsException
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_IndexOutOfBoundsException

#include "java/lang/IndexOutOfBoundsException.h"

#ifndef _JC_java_lang_ArrayIndexOutOfBoundsException_H_
#define _JC_java_lang_ArrayIndexOutOfBoundsException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_ArrayIndexOutOfBoundsException$sub_refs	_jc_java_lang_ArrayIndexOutOfBoundsException$sub_refs;
typedef struct _jc_java_lang_ArrayIndexOutOfBoundsException$sub_nonrefs	_jc_java_lang_ArrayIndexOutOfBoundsException$sub_nonrefs;
typedef struct _jc_java_lang_ArrayIndexOutOfBoundsException$refs	_jc_java_lang_ArrayIndexOutOfBoundsException$refs;
typedef struct _jc_java_lang_ArrayIndexOutOfBoundsException$nonrefs	_jc_java_lang_ArrayIndexOutOfBoundsException$nonrefs;
typedef struct _jc_java_lang_ArrayIndexOutOfBoundsException$object	_jc_java_lang_ArrayIndexOutOfBoundsException$object;

typedef struct _jc_java_lang_ArrayIndexOutOfBoundsException$fields_struct	_jc_java_lang_ArrayIndexOutOfBoundsException$fields_struct;
typedef const struct _jc_java_lang_ArrayIndexOutOfBoundsException$vmethods	_jc_java_lang_ArrayIndexOutOfBoundsException$vmethods;
typedef const struct _jc_java_lang_ArrayIndexOutOfBoundsException$vtable	_jc_java_lang_ArrayIndexOutOfBoundsException$vtable;
typedef const struct _jc_java_lang_ArrayIndexOutOfBoundsException$vtype	_jc_java_lang_ArrayIndexOutOfBoundsException$vtype;

// Class fields structure
struct _jc_java_lang_ArrayIndexOutOfBoundsException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_ArrayIndexOutOfBoundsException$fields_struct _jc_java_lang_ArrayIndexOutOfBoundsException$class_fields;

// Constructors
extern void _jc_java_lang_ArrayIndexOutOfBoundsException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_ArrayIndexOutOfBoundsException$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_ArrayIndexOutOfBoundsException$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_lang_ArrayIndexOutOfBoundsException$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_lang_ArrayIndexOutOfBoundsException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_ArrayIndexOutOfBoundsException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_ArrayIndexOutOfBoundsException$vmethods {
};

// Vtable
struct _jc_java_lang_ArrayIndexOutOfBoundsException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_IndexOutOfBoundsException$vmethods	java_lang_IndexOutOfBoundsException;
	_jc_java_lang_ArrayIndexOutOfBoundsException$vmethods	java_lang_ArrayIndexOutOfBoundsException;
};

// Vtype
struct _jc_java_lang_ArrayIndexOutOfBoundsException$vtype {
	_jc_type			type;
	_jc_java_lang_ArrayIndexOutOfBoundsException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_ArrayIndexOutOfBoundsException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_ArrayIndexOutOfBoundsException$refs {
    _jc_java_lang_ArrayIndexOutOfBoundsException$sub_refs	java_lang_ArrayIndexOutOfBoundsException;
    _jc_java_lang_IndexOutOfBoundsException$sub_refs	java_lang_IndexOutOfBoundsException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_ArrayIndexOutOfBoundsException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_ArrayIndexOutOfBoundsException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_IndexOutOfBoundsException$sub_nonrefs	java_lang_IndexOutOfBoundsException;
    _jc_java_lang_ArrayIndexOutOfBoundsException$sub_nonrefs	java_lang_ArrayIndexOutOfBoundsException;
};

// Object instance structure
struct _jc_java_lang_ArrayIndexOutOfBoundsException$object {
	_jc_java_lang_ArrayIndexOutOfBoundsException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_ArrayIndexOutOfBoundsException$vtype	*vtype;
	_jc_java_lang_ArrayIndexOutOfBoundsException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_ArrayIndexOutOfBoundsException$vtype _jc_java_lang_ArrayIndexOutOfBoundsException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_ArrayIndexOutOfBoundsException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_ArrayIndexOutOfBoundsException$class_object;

#endif	/* _JC_java_lang_ArrayIndexOutOfBoundsException_H_ */
